__name__ = "deciphon-api"
__version__ = "0.4.3"

__all__ = [
    "__name__",
    "__version__",
]
